<?php

/**
 * @file
 * Drop2S3 Administrative form and functions.
 */

/**
 * Drop2S3 settings form.
 */
function drop2s3_settings_form() {
  $form = array();

  $form['aws_credentials'] = array(
    '#type' => 'fieldset',
    '#title' => t('Amazon Web Services Credentials'),
    '#description' => t("To configure your Amazon Web Services credentials, enter the values in the appropriate fields below."
    ),
    '#collapsible' => TRUE,
    // Simplify the form by collapsing this fieldset if it's already been
    // configured.
    '#collapsed' => variable_get('drop2s3_awssdk2_access_key') && variable_get('drop2s3_awssdk2_secret_key'),
  );

  $form['aws_credentials']['drop2s3_awssdk2_access_key'] = array(
    '#type' => 'textfield',
    '#title' => t('Amazon Web Services Access Key'),
    '#default_value' => variable_get('drop2s3_awssdk2_access_key'),
  );

  $form['aws_credentials']['drop2s3_awssdk2_secret_key'] = array(
    '#type' => 'textfield',
    '#title' => t('Amazon Web Services Secret Key'),
    '#default_value' => variable_get('drop2s3_awssdk2_secret_key'),
  );

  $form['drop2s3_bucket'] = array(
    '#type' => 'textfield',
    '#title' => t('S3 Bucket Name'),
    '#default_value' => variable_get('drop2s3_bucket'),
    '#required' => TRUE,
  );

  $form['advanced'] = array(
    '#type' => 'fieldset',
    '#title' => t('Advanced Configuration Options'),
    '#collapsible' => TRUE,
    // This is always collapsed because most users won't need to alter these
    // settings.
    '#collapsed' => TRUE,
  );

  $form['advanced']['drop2s3_encryption'] = array(
    '#type' => 'select',
    '#options' => array(
      '' => t('None'),
      'AES256' => t('AES256'),
      'aws:kms' => t('aws:kms'),
    ),
    '#title' => t('Server-Side Encryption'),
    '#default_value' => variable_get('drop2s3_encryption'),
    '#description' => t(
      'If your bucket requires !ENCRYPTION, you can specify the encryption algorithm here',
      array(
        '!ENCRYPTION' => l(t('server-side encryption'),
          'http://docs.aws.amazon.com/AmazonS3/latest/dev/UsingServerSideEncryption.html'
        ),
      )
    ),
  );

  $form['advanced']['drop2s3_root_folder'] = array(
    '#type' => 'textfield',
    '#title' => t('Root Folder'),
    '#default_value' => variable_get('drop2s3_root_folder'),
    '#description' => t(
      'S3 File System uses the specified folder as the root of the file system within your bucket (if blank, the bucket
      root is used). This is helpful when your bucket is used by multiple sites, or has additional data in it which
      drop2s3 should not interfere with.<br>
      This setting is case sensitive. Do not include leading or trailing slashes.<br>
      Changing this setting <b>will not</b> move any files. If you\'ve already uploaded files to S3 through S3 File
      System, you will need to manually move them into this folder.'
    ),
  );

  $form['debug_config'] = array(
    '#type' => 'fieldset',
    '#title' => t('Debug configuration'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
  );

  $form['debug_config']['drop2s3_console_logging'] = array(
    '#type' => 'checkbox',
    '#title' => t('Enable EvaporateJS console logging.'),
    '#default_value' => variable_get('drop2s3_console_logging', 0),
  );

  $form['debug_config']['drop2s3_cache_presigned_url'] = array(
    '#type' => 'checkbox',
    '#title' => t('Enable cache presigned url.'),
    '#default_value' => variable_get('drop2s3_cache_presigned_url', 0),
  );

  return system_settings_form($form);
}
